<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:param name="target.window">_blank</xsl:param>
	<xsl:param name="baseActionURL">no parameter passed</xsl:param>
	<xsl:param name="mediaPath">media/org/jasig/portal/channels/bookmarks</xsl:param>

	<xsl:template match="xbel" name="BookmarkTree">
	<xsl:param name="TreeMode">View</xsl:param>

	<div>
	<xsl:choose>
		<!-- Display an only one CSS class. Bookmarks class is repeated in other nodes. -->
		<xsl:when test="$TreeMode='View'">
			<xsl:attribute name="class">bookmarks</xsl:attribute>
		</xsl:when>
		<xsl:otherwise></xsl:otherwise>
	</xsl:choose>

	<xsl:if test="$TreeMode='AddFolder' or $TreeMode='AddBookmark'">
		<input type="radio" name="FolderRadioButton" value="RootLevel" checked="checked" style="vertical-align: middle;" />
		New Top Level <xsl:value-of select="substring-after($TreeMode,'Add')"/>
	</xsl:if>

		<ul class="bookmark-root">

		<xsl:apply-templates select="/xbel/folder">
			<xsl:sort select="title"/>
			<xsl:with-param name="TreeMode">
				<xsl:value-of select="$TreeMode"/>
			</xsl:with-param>
		</xsl:apply-templates>
	
		<xsl:apply-templates select="/xbel/bookmark">
			<xsl:sort select="title"/>
			<xsl:with-param name="TreeMode">
				<xsl:value-of select="$TreeMode"/>
			</xsl:with-param>
		</xsl:apply-templates>
		</ul>
	</div>

	</xsl:template>

	<xsl:template match="folder">
	<xsl:param name="TreeMode">View</xsl:param>

	<li>
	<xsl:attribute name="class">
		<!-- Display an open or closed folder icon -->
		<xsl:choose>
			<xsl:when test="@folded='yes'">shut</xsl:when>
			<xsl:otherwise>open</xsl:otherwise>
		</xsl:choose>
	</xsl:attribute>

	<!-- Display a radio button or checkbox if in edit mode -->
	<xsl:choose>
		<xsl:when test="$TreeMode='AddFolder' or $TreeMode='AddBookmark' or $TreeMode='EditFolder'">
			<input type="radio" name="FolderRadioButton" value="{@id}" />
		</xsl:when>
		<xsl:when test="$TreeMode='DeleteFolder'">
			<input type="checkbox" name="FolderCheckbox#{@id}" />
		</xsl:when>
	</xsl:choose>

	<!-- Display folder title and correct URL -->
	<xsl:choose>
		<xsl:when test="@folded='yes'">
			<a href="{$baseActionURL}?command=unfold&amp;ID={@id}">
				<xsl:attribute name="title">
					<xsl:value-of select="title"/>
				</xsl:attribute>
				<xsl:value-of select="title"/>
			</a>
		</xsl:when>
		<xsl:otherwise>
			<a href="{$baseActionURL}?command=fold&amp;ID={@id}">
				<xsl:attribute name="title">
					<xsl:value-of select="title"/>
				</xsl:attribute>
				<xsl:value-of select="title"/>
			</a>
		</xsl:otherwise>
	</xsl:choose>

	</li>

	<!-- Recurse through the subtrees if the folder is open and indent subitems -->
	<xsl:if test="@folded='no'">
		<li class="tree">
			<ul>
			<xsl:apply-templates select="folder">
				<xsl:sort select="title"/>
				<xsl:with-param name="TreeMode">
					<xsl:value-of select="$TreeMode"/>
				</xsl:with-param>
			</xsl:apply-templates>
			<xsl:apply-templates select="bookmark">
				<xsl:sort select="title"/>
				<xsl:with-param name="TreeMode">
					<xsl:value-of select="$TreeMode"/>
				</xsl:with-param>
			</xsl:apply-templates>
			</ul>
		</li>
	</xsl:if>

	</xsl:template>

	<xsl:template match="bookmark">
	<xsl:param name="TreeMode">View</xsl:param>

	<li>
	<xsl:choose>
		<!-- Display a radio button or checkbox if in edit mode -->
		<xsl:when test="$TreeMode='EditBookmark'">
			<input type="radio" name="BookmarkRadioButton" value="{@id}" />
		</xsl:when>
		<xsl:when test="$TreeMode='DeleteBookmark'">
			<input type="checkbox" name="BookmarkCheckbox#{@id}" />
		</xsl:when>
	</xsl:choose>
	<a href="{@href}" target="_blank">
		<xsl:attribute name="title">
			<xsl:value-of select="desc"/>
		</xsl:attribute>
		<xsl:value-of select="title"/>
	</a>
	</li>

	</xsl:template>

</xsl:stylesheet>
